==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/fr.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "L'obtention des jetons de requête a échoué. Vérifiez que votre clé d'application et votre mot de passe sont corrects.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "L'obtention des jetons d'accès a échoué. Vérifiez que votre clé d'application et votre mot de passe sont corrects.",
    "Please provide a valid app key and secret." : "Veuillez fournir une clé d'application et un mot de passe valides.",
    "Step 1 failed. Exception: %s" : "L’étape 1 a échoué. Erreur : %s",
    "Step 2 failed. Exception: %s" : "L’étape 2 a échoué. Erreur : %s",
    "External storage" : "Stockage externe",
    "Storage with id \"%i\" not found" : "Stockage avec l'id \"%i\" non trouvé",
    "Invalid backend or authentication mechanism class" : "Service ou méthode d'authentification non valable",
    "Invalid mount point" : "Point de montage non valide",
    "Objectstore forbidden" : "\"Objectstore\" interdit",
    "Invalid storage backend \"%s\"" : "Service de stockage non valide : \"%s\"",
    "Not permitted to use backend \"%s\"" : "Non autorisé à utiliser le service \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Non autorisé à utiliser le mécanisme d'authentification \"%s\"",
    "Unsatisfied backend parameters" : "Paramètres manquants pour le service",
    "Unsatisfied authentication mechanism parameters" : "Paramètres manquants pour la méthode d'authentification",
    "Personal" : "Personnel",
    "System" : "Système",
    "Grant access" : "Autoriser l'accès",
    "Access granted" : "Accès autorisé",
    "Error configuring OAuth1" : "Erreur lors de la configuration de OAuth1",
    "Error configuring OAuth2" : "Erreur lors de la configuration de OAuth2",
    "Generate keys" : "Générer des clés",
    "Error generating key pair" : "Erreur lors de la génération des clés",
    "Enable encryption" : "Activer le chiffrement",
    "Enable previews" : "Activer les prévisualisations",
    "Check for changes" : "Rechercher les modifications",
    "Never" : "Jamais",
    "Once every direct access" : "Une fois à chaque accès direct",
    "Every time the filesystem is used" : "Chaque fois que le système de fichiers est utilisé",
    "All users. Type to select user or group." : "Tous les utilisateurs. Cliquez ici pour restreindre.",
    "(group)" : "(groupe)",
    "Saved" : "Sauvegardé",
    "Access key" : "Clé d'accès",
    "Secret key" : "Clé secrète",
    "Builtin" : "Inclus",
    "None" : "Aucun",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Client",
    "Client secret" : "Secret client",
    "OpenStack" : "OpenStack",
    "Username" : "Nom d'utilisateur",
    "Password" : "Mot de passe",
    "API key" : "Clé API",
    "Username and password" : "Nom d'utilisateur et mot de passe",
    "Session credentials" : "Informations d'identification de session",
    "RSA public key" : "Clé publique RSA",
    "Public key" : "Clef publique",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nom de l'hôte",
    "Port" : "Port",
    "Region" : "Région",
    "Enable SSL" : "Activer SSL",
    "Enable Path Style" : "Accès par path",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sous-dossier distant",
    "Secure https://" : "Sécurisation https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Hôte",
    "Secure ftps://" : "Sécurisation ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Emplacement",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP avec identification par clé",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Partage",
    "Domain" : "Domaine",
    "SMB / CIFS using OC login" : "SMB / CIFS en utilisant les identifiants OC",
    "Username as share" : "Nom d'utilisateur comme nom de partage",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nom du service",
    "<b>Note:</b> " : "<b>Attention :</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Attention :</b> La prise en charge de cURL par PHP n'est pas activée ou installée. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Attention : </b> La prise en charge du FTP par PHP n'est pas activée ou installée. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Attention : </b> \"%s\" n'est pas installé. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
    "No external storage configured" : "Aucun stockage externe configuré",
    "You can add external storages in the personal settings" : "Vous pouvez ajouter des stockages externes via vos paramètres personnels",
    "Name" : "Nom",
    "Storage type" : "Type de stockage",
    "Scope" : "Portée",
    "External Storage" : "Stockage externe",
    "Folder name" : "Nom du dossier",
    "Authentication" : "Authentification",
    "Configuration" : "Configuration",
    "Available for" : "Disponible pour",
    "Advanced settings" : "Paramètres avancés",
    "Delete" : "Supprimer",
    "Add storage" : "Ajouter un support de stockage",
    "Enable User External Storage" : "Autoriser les utilisateurs à ajouter des stockages externes",
    "Allow users to mount the following external storage" : "Autoriser les utilisateurs à monter les stockages externes suivants"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-9.1.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/fr.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "L'obtention des jetons de requête a échoué. Vérifiez que votre clé d'application et votre mot de passe sont corrects.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "L'obtention des jetons d'accès a échoué. Vérifiez que votre clé d'application et votre mot de passe sont corrects.",
    "Please provide a valid app key and secret." : "Veuillez fournir une clé d'application et un mot de passe valides.",
    "Step 1 failed. Exception: %s" : "L’étape 1 a échoué. Erreur : %s",
    "Step 2 failed. Exception: %s" : "L’étape 2 a échoué. Erreur : %s",
    "External storage" : "Stockage externe",
    "Dropbox App Configuration" : "Configuration de l'application Dropbox",
    "Google Drive App Configuration" : "Configuration de l'application Google Drive",
    "Personal" : "Personnel",
    "System" : "Système",
    "Grant access" : "Autoriser l'accès",
    "Error configuring OAuth1" : "Erreur lors de la configuration de OAuth1",
    "Error configuring OAuth2" : "Erreur lors de la configuration de OAuth2",
    "Generate keys" : "Générer des clés",
    "Error generating key pair" : "Erreur lors de la génération des clés",
    "All users. Type to select user or group." : "Tous les utilisateurs. Cliquez ici pour restreindre.",
    "(group)" : "(groupe)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilité avec l'encodage Mac NFD (lent)",
    "Admin defined" : "Défini par l'administrateur",
    "Saved" : "Sauvegardé",
    "Empty response from the server" : "Réponse vide du serveur",
    "Couldn't access. Please logout and login to activate this mount point" : "Impossible d'accéder. Veuillez vous déconnecter et vous reconnecter pour activer ce point de montage.",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Impossible d'obtenir l'information depuis le serveur ownCloud : {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Impossible de récupérer la liste des points de montage externes : {type}",
    "There was an error with message: " : "Il y a eu une erreur avec le message :",
    "External mount error" : "Erreur de point de montage externe",
    "external-storage" : "external-storage",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Impossible d'obtenir la liste des points de montage des disques réseaux Windows : Réponse vide du serveur",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Certains points de montage externes configurés ne sont pas connectés. Veuillez cliquer sur la(les) ligne(s) rouge(s) pour plus d'informations",
    "Please enter the credentials for the {mount} mount" : "Veuillez entrer les identifiants pour le montage {mount}",
    "Username" : "Nom d'utilisateur",
    "Password" : "Mot de passe",
    "Credentials saved" : "Identifiants sauvegardés",
    "Credentials saving failed" : "La sauvegarde des identifiants a échoué",
    "Credentials required" : "Des informations d'identification sont requises",
    "Save" : "Enregistrer",
    "Storage with id \"%i\" not found" : "Stockage avec l'id \"%i\" non trouvé",
    "Invalid backend or authentication mechanism class" : "Service ou méthode d'authentification non valable",
    "Invalid mount point" : "Point de montage non valide",
    "Objectstore forbidden" : "\"Objectstore\" interdit",
    "Invalid storage backend \"%s\"" : "Service de stockage non valide : \"%s\"",
    "Not permitted to use backend \"%s\"" : "Non autorisé à utiliser le service \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Non autorisé à utiliser le mécanisme d'authentification \"%s\"",
    "Unsatisfied backend parameters" : "Paramètres manquants pour le service",
    "Unsatisfied authentication mechanism parameters" : "Paramètres manquants pour la méthode d'authentification",
    "Insufficient data: %s" : "Données insuffisantes : %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Le support de stockage d'id \"%i\" n'est pas modifiable par les utilisateurs",
    "Access key" : "Clé d'accès",
    "Secret key" : "Clé secrète",
    "Builtin" : "Intégré",
    "None" : "Aucun",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID Client",
    "Client secret" : "Secret client",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Tenant name",
    "Identity endpoint URL" : "Identity endpoint URL",
    "Rackspace" : "Rackspace",
    "API key" : "Clé API",
    "Username and password" : "Nom d'utilisateur et mot de passe",
    "Log-in credentials, save in session" : "Identifiants de connexion, sauvegardés pour la session",
    "RSA public key" : "Clé publique RSA",
    "Public key" : "Clef publique",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nom de l'hôte",
    "Port" : "Port",
    "Region" : "Région",
    "Enable SSL" : "Activer SSL",
    "Enable Path Style" : "Accès par path",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Sous-dossier distant",
    "Secure https://" : "Sécurisation https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Hôte",
    "Secure ftps://" : "Sécurisation ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Emplacement",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Racine",
    "SFTP with secret key login" : "SFTP avec identification par clé",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Partage",
    "Domain" : "Domaine",
    "SMB / CIFS using OC login" : "SMB / CIFS en utilisant les identifiants OC",
    "Username as share" : "Nom d'utilisateur comme nom de partage",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Nom du service",
    "Request timeout (seconds)" : "Délai d'expiration des requêtes (en secondes)",
    "<b>Note:</b> " : "<b>Attention :</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Attention :</b> La prise en charge de cURL par PHP n'est pas activée ou installée. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Attention : </b> La prise en charge du FTP par PHP n'est pas activée ou installée. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Attention : </b> \"%s\" n'est pas installé. Le montage de %s n'est pas possible. Contactez votre administrateur système pour l'installer.",
    "No external storage configured" : "Aucun stockage externe configuré",
    "You can add external storages in the personal settings" : "Vous pouvez ajouter des stockages externes via vos paramètres personnels",
    "Name" : "Nom",
    "Storage type" : "Type de stockage",
    "Scope" : "Portée",
    "Enable encryption" : "Activer le chiffrement",
    "Enable previews" : "Activer les prévisualisations",
    "Enable sharing" : "Permettre le partage",
    "Check for changes" : "Rechercher les modifications",
    "Never" : "Jamais",
    "Once every direct access" : "Une fois à chaque accès direct",
    "External Storage" : "Stockage externe",
    "Folder name" : "Nom du dossier",
    "Authentication" : "Authentification",
    "Configuration" : "Configuration",
    "Available for" : "Disponible pour",
    "Add storage" : "Ajouter un support de stockage",
    "Advanced settings" : "Paramètres avancés",
    "Delete" : "Supprimer",
    "Allow users to mount external storage" : "Autoriser les utilisateurs à monter des espaces de stockage externes",
    "Allow users to mount the following external storage" : "Autoriser les utilisateurs à monter les stockages externes suivants"
},
"nplurals=2; plural=(n > 1);");
